@@ -6,11 +6,14 @@ makeRLearner.classif.gbm = function() {
     par.set = makeParamSet(
       makeDiscreteLearnerParam(id = "distribution", values = c("bernoulli", "adaboost", "gaussian", "laplace", "huberized", "multinomial", "poisson", "pairwise")),
       makeIntegerLearnerParam(id = "n.trees", default = 100L, lower = 1L),
+      makeIntegerLearnerParam(id = "cv.folds", default = 0L),
       makeIntegerLearnerParam(id = "interaction.depth", default = 1L, lower = 1L),
       makeIntegerLearnerParam(id = "n.minobsinnode", default = 10L, lower = 1L),
       makeNumericLearnerParam(id = "shrinkage", default = 0.001, lower = 0),
       makeNumericLearnerParam(id = "bag.fraction", default = 0.5, lower = 0, upper = 1),
-      makeNumericLearnerParam(id = "train.fraction", default = 1, lower = 0, upper = 1)
+      makeNumericLearnerParam(id = "train.fraction", default = 1, lower = 0, upper = 1),
+      makeLogicalLearnerParam(id = "keep.data", default = TRUE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "verbose", default = FALSE, tunable = FALSE)
     ),
     properties = c("twoclass", "multiclass", "missings", "numerics", "factors", "prob", "weights"),
     name = "Gradient Boosting Machine",
@@ -21,25 +24,27 @@ makeRLearner.classif.gbm = function() {
 
 #' @export
 trainLearner.classif.gbm = function(.learner, .task, .subset, .weights = NULL,  ...) {
-  if (length(.task$task.desc$class.levels) == 2L)
+  td = getTaskDescription(.task)
+  if (length(td$class.levels) == 2L)
     d = getTaskData(.task, .subset, recode.target = "01")
   else
     d = getTaskData(.task, .subset)
   if (is.null(.weights)) {
     f = getTaskFormula(.task)
-    gbm::gbm(f, data = d, keep.data = FALSE, verbose = FALSE, ...)
+    gbm::gbm(f, data = d, keep.data = FALSE, ...)
   } else  {
-    f = as.formula(getTaskFormulaAsString(.task))
-    gbm::gbm(f, data = d, keep.data = FALSE, verbose = FALSE, weights = .weights, ...)
+    f = getTaskFormula(.task)
+    gbm::gbm(f, data = d, keep.data = FALSE, weights = .weights, ...)
   }
 }
 
 #' @export
 predictLearner.classif.gbm = function(.learner, .model, .newdata, ...) {
+  td = .model$task.desc
   m = .model$learner.model
   p = gbm::predict.gbm(m, newdata = .newdata, type = "response", n.trees = m$n.trees, single.tree = FALSE, ...)
-  if (length(.model$task.desc$class.levels) == 2) {
-    levs = c(.model$task.desc$negative, .model$task.desc$positive)
+  if (length(td$class.levels) == 2L) {
+    levs = c(td$negative, td$positive)
     if (.learner$predict.type == "prob") {
       y = matrix(0, ncol = 2, nrow = nrow(.newdata))
       colnames(y) = levs
