@@ -7,7 +7,7 @@ makeRLearner.classif.logreg = function() {
     properties = c("twoclass", "numerics", "factors", "prob", "weights"),
     name = "Logistic Regression",
     short.name = "logreg",
-    note = ""
+    note = "Delegates to glm with family binomial/logit."
   )
 }
 
@@ -22,12 +22,7 @@ predictLearner.classif.logreg = function(.learner, .model, .newdata, ...) {
   x = predict(.model$learner.model, newdata = .newdata, type = "response", ...)
   levs = .model$task.desc$class.levels
   if (.learner$predict.type == "prob") {
-    # FIXME: this should be a helper function
-    y = matrix(0, ncol = 2L, nrow = nrow(.newdata))
-    colnames(y) = levs
-    y[, 1L] = 1-x
-    y[, 2L] = x
-    return(y)
+    propVectorToMatrix(x, levs)
   } else {
     levs = .model$task.desc$class.levels
     p = as.factor(ifelse(x > 0.5, levs[2L], levs[1L]))
