@@ -9,15 +9,17 @@ makeRLearner.classif.randomForest = function() {
       makeLogicalLearnerParam(id = "replace", default = TRUE),
       makeNumericVectorLearnerParam(id = "classwt", lower = 0),
       makeNumericVectorLearnerParam(id = "cutoff", lower = 0, upper = 1),
-      makeIntegerVectorLearnerParam(id = "sampsize", lower = 0L),
+      makeIntegerLearnerParam(id = "sampsize", lower = 1L),
       makeIntegerLearnerParam(id = "nodesize", default = 1L, lower = 1L),
       makeIntegerLearnerParam(id = "maxnodes", lower = 1L),
       makeLogicalLearnerParam(id = "importance", default = FALSE),
       makeLogicalLearnerParam(id = "localImp", default = FALSE),
-      makeLogicalLearnerParam(id = "norm.votes", default = TRUE),
-      makeLogicalLearnerParam(id = "keep.inbag", default = FALSE)
+      makeLogicalLearnerParam(id = "norm.votes", default = TRUE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "do.trace", default = FALSE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "keep.inbag", default = FALSE, tunable = FALSE)
     ),
-    properties = c("twoclass", "multiclass", "numerics", "factors", "ordered", "prob"),
+    properties = c("twoclass", "multiclass", "numerics", "factors", "ordered", "prob", "class.weights"),
+    class.weights.param = "classwt",
     name = "Random Forest",
     short.name = "rf"
     )
