@@ -20,7 +20,7 @@ makeRLearner.classif.rrlda = function() {
 
 #' @export
 trainLearner.classif.rrlda = function(.learner, .task, .subset, .weights = NULL,  ...) {
-  d = getTaskData(.task, .subset, target.extra = TRUE)
+  d = getTaskData(.task, .subset, target.extra = TRUE, recode.target = "drop.levels")
   rrlda::rrlda(x = d$data, grouping = d$target, ...)
 }
 
