@@ -5,12 +5,21 @@ makeRLearner.regr.randomForestSRC = function() {
     package = "randomForestSRC",
     par.set = makeParamSet(
       makeIntegerLearnerParam(id = "ntree", default = 1000L, lower = 1L),
-      makeDiscreteLearnerParam(id = "bootstrap", values = c("by.root", "by.node", "none"), default = "by.root"),
+      makeDiscreteLearnerParam(id = "bootstrap", default = "by.root",
+        values = c("by.root", "by.node", "none")),
       makeIntegerLearnerParam(id = "mtry", lower = 1L),
       makeIntegerLearnerParam(id = "nodesize", lower = 1L, default = 5L),
-      makeDiscreteLearnerParam(id = "na.action", values = c("na.omit", "na.impute"), default = "na.impute", when = "both"),
+      makeIntegerLearnerParam(id = "nsplit", default = 0L),
+      makeDiscreteLearnerParam(id = "na.action", default = "na.impute",
+        values = c("na.omit", "na.impute"), when = "both"),
       makeIntegerLearnerParam(id = "nimpute", default = 1L, lower = 1L),
-      makeNumericVectorLearnerParam(id = "xwar.wt", lower = 0)
+      makeNumericVectorLearnerParam(id = "xwar.wt", lower = 0),
+      makeLogicalLearnerParam(id = "forest", default = TRUE, tunable = FALSE),
+      makeIntegerLearnerParam(id = "seed", tunable = FALSE),
+      makeLogicalLearnerParam(id = "do.trace", default = FALSE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "membership", default = TRUE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "statistics", default = FALSE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "fast.restore", default = FALSE, tunable = FALSE)
     ),
     par.vals = list(na.action = "na.impute"),
     properties = c("missings", "numerics", "factors"),
