@@ -52,7 +52,7 @@
 #'   For classification: Color of misclassified data points.
 #'   Default is \dQuote{white}
 #' @param err.size [\code{integer(1)}]\cr
-#'   For classification: Size of of misclassified data points.
+#'   For classification: Size of misclassified data points.
 #'   Default is \code{pointsize}.
 #' @param greyscale [\code{logical(1)}]\cr
 #'   Should the plot be greyscale completely?
@@ -73,7 +73,7 @@ plotLearnerPrediction = function(learner, task, features = NULL, measures, cv =
     checkClass(task, "RegrTask"),
     checkClass(task, "ClusterTask")
   )
-  td = task$task.desc
+  td = getTaskDescription(task)
 
   # features and dimensionality
   fns = getTaskFeatureNames(task)
@@ -123,9 +123,9 @@ plotLearnerPrediction = function(learner, task, features = NULL, measures, cv =
 
   # predictions
   # if learner supports prob or se, enable it
-  if (td$type == "regr" && taskdim == 1L && hasProperties(learner, "se"))
+  if (td$type == "regr" && taskdim == 1L && hasLearnerProperties(learner, "se"))
     learner = setPredictType(learner, "se")
-  if (td$type == "classif" && hasProperties(learner, "prob"))
+  if (td$type == "classif" && hasLearnerProperties(learner, "prob"))
     learner = setPredictType(learner, "prob")
   mod = train(learner, task)
   pred.train = predict(mod, task)
@@ -168,9 +168,9 @@ plotLearnerPrediction = function(learner, task, features = NULL, measures, cv =
       NULL
     if (taskdim == 2L) {
       p = ggplot(grid, aes_string(x = x1n, y = x2n))
-      if (hasProperties(learner, "prob") && prob.alpha) {
+      if (hasLearnerProperties(learner, "prob") && prob.alpha) {
         # max of rows is prob for selected class
-        prob = apply(getProbabilities(pred.grid, cl = td$class.levels), 1, max)
+        prob = apply(getPredictionProbabilities(pred.grid, cl = td$class.levels), 1, max)
         grid$.prob.pred.class = prob
         p = p + geom_tile(data = grid, mapping = aes_string(fill = target, alpha = ".prob.pred.class"),
           show_guide = TRUE)
@@ -208,7 +208,7 @@ plotLearnerPrediction = function(learner, task, features = NULL, measures, cv =
       p = p + geom_point(data = data, mapping = aes_string(y = target), size = pointsize)
       p = p + geom_line(data = grid, mapping = aes_string(y = target))
       # show se band
-      if (se.band && hasProperties(learner, "se")) {
+      if (se.band && hasLearnerProperties(learner, "se")) {
         grid$.se = pred.grid$data$se
         grid$.ymin = grid[, target] - grid$.se
         grid$.ymax = grid[, target] + grid$.se
