@@ -1,14 +1,17 @@
 context("BaggingWrapper")
 
 test_that("BaggingWrapper", {
+  # classification
   lrn1 = makeLearner("classif.rpart")
   lrn2 = makeBaggingWrapper(lrn1, bw.iters = 3L)
   m = train(lrn2, multiclass.task)
+  expect_is(m, "BaggingModel")
+  expect_is(m, "HomogeneousEnsembleModel")
   expect_true(!inherits(m, "FailureModel"))
-  bms = getBaggingModels(m, learner.models = FALSE)
+  bms = getLearnerModel(m, more.unwrap = FALSE)
   expect_true(is.list(bms) && length(bms) == lrn2$par.vals$bw.iters)
   expect_true(inherits(bms[[1L]], "WrappedModel"))
-  bms = getBaggingModels(m, learner.models = TRUE)
+  bms = getLearnerModel(m, more.unwrap = TRUE)
   expect_true(is.list(bms) && length(bms) == lrn2$par.vals$bw.iters)
   expect_true(inherits(bms[[1L]], "rpart"))
   rdesc = makeResampleDesc("CV", iters = 2)
@@ -16,20 +19,21 @@ test_that("BaggingWrapper", {
   expect_true(r$aggr[[1L]] < 0.15)
   lrn2 = makeBaggingWrapper(lrn1, bw.size = 0.1, bw.replace = FALSE)
   m = train(lrn2, multiclass.task)
-  bms = getBaggingModels(m)
+  bms = getLearnerModel(m)
   expect_equal(unique(sapply(bms, function(m) length(bms[[1]]$subset))), 15L)
   lrn2 = makeBaggingWrapper(lrn1, bw.iters = 3L, bw.feats = 0.5)
   m = train(lrn2, multiclass.task)
-  bms = getBaggingModels(m)
+  bms = getLearnerModel(m)
   expect_equal(unique(sapply(bms, function(m) length(bms[[1]]$features))), 2L)
   lrn1 = makeLearner("classif.rpart")
   lrn2 = makeBaggingWrapper(lrn1, bw.iters = 3L)
   lrn2 = setPredictType(lrn2, "prob")
   m = train(lrn2, binaryclass.task)
   p = predict(m, binaryclass.task)
-  getProbabilities(p)
+  getPredictionProbabilities(p)
   r = resample(lrn2, binaryclass.task, rdesc, measures = auc)
 
+  # regression
   lrn1 = makeLearner("regr.rpart")
   lrn2 = makeBaggingWrapper(lrn1, bw.iters = 3L)
   m = train(lrn2, regr.task)
@@ -39,6 +43,8 @@ test_that("BaggingWrapper", {
   lrn2 = setPredictType(lrn2, "se")
   m = train(lrn2, regr.task)
   p = predict(m, regr.task)
+
+  # blocking for BaggingWrapper is testet ind test_base_blocking.R
 })
 
 test_that("BaggingWrapper works with feature subsampling", {
