@@ -19,4 +19,10 @@ test_that("Learner", {
 
   wl = makeLearner("regr.lm", config = list(on.learner.error = "quiet"))
   expect_equal(wl$config$on.learner.error, "quiet")
+
+  expect_error(makeLearner("classif.lda", predict.threshold = 1, "'prob' must hold"))
+
+  #  Learner cannot use expression in param requires, see #369
+  expect_error(makeLearner("classif.__mlrmocklearners__5"), "used 'expression'")
 })
+
