@@ -16,8 +16,8 @@ test_that("basic PreprocWrapperCaret works", {
   expect_true(perf2 > perf)
 
   mod = caret::preProcess(x = multiclass.df[multiclass.train.inds,1:4], method = c("BoxCox", "pca", "scale", "center"), pcaComp = 2)
-  mod$method = sort(mod$method)
-  ctrl$method = sort(ctrl$method)
+  mod$method = mod$method[order(names(mod$method))]
+  ctrl$method = ctrl$method[order(names(ctrl$method))]
   mod$call = NULL
   ctrl$call = NULL
   expect_equal(mod, ctrl)
@@ -26,5 +26,5 @@ test_that("basic PreprocWrapperCaret works", {
 test_that("PreprocWrapperCaret supports missing values", {
   lrn1 = makeLearner("classif.svm")
   lrn2 = makePreprocWrapperCaret(lrn1, ppc.knnImpute = TRUE)
-  expect_true(hasProperties(lrn2, props = "missings"))
+  expect_true(hasLearnerProperties(lrn2, props = "missings"))
 })
