@@ -24,8 +24,8 @@ test_that("classif_multinom", {
   m = train(wl, binaryclass.task)
   p = predict(m, newdata=binaryclass.df)
   rr = p$data$response
-  pp = getProbabilities(p)
+  pp = getPredictionProbabilities(p)
   i = as.integer(pp < 0.5) + 1
-  labs = as.factor(binaryclass.task$task.desc$class.levels[i])
+  labs = as.factor(getTaskClassLevels(binaryclass.task)[i])
   expect_equal(rr, labs)
 })
