@@ -39,9 +39,20 @@ test_that("fix factors work", {
   test = setdiff(1:n, train)
 
   task = makeRegrTask(data = data[train, ], target = "Sepal.Length")
-  learner = makeLearner("regr.randomForest", fix.factors = TRUE)
+  learner = makeLearner("regr.randomForest", fix.factors.prediction = TRUE)
   model = train(learner, task)
   newdata = data[head(test, 1L), ]
   newdata$Species = droplevels(newdata$Species)
   expect_is(predict(model, newdata = newdata), "Prediction")
 })
+
+test_that("different se.methods work", {
+  se.methods = c("bootstrap", "jackknife", "noisy.bootstrap")
+  for (se.method in se.methods) {
+    keep.inbag = se.method == "jackknife"
+    learner = makeLearner("regr.randomForest", predict.type = "se", se.method = se.method, ntree = 10, keep.inbag = keep.inbag)
+    model = train(learner, task = regr.task, subset = regr.train.inds)
+    pred = predict(model, task = regr.task, subset = regr.test.inds)
+    expect_true(is.numeric(pred$data$se))
+  }
+})
